@@ -49,7 +49,7 @@ except ImportError:
     pep8 = None
 
 
-__version__ = '0.7.3'
+__version__ = '0.8'
 
 
 PEP8_BIN = 'pep8'
@@ -100,6 +100,20 @@ class FixPEP8(object):
 
     """Fix invalid code.
 
+    Fixer methods are prefixed "fix_". The _fix_source() method looks for these
+    automatically.
+
+    The fixer method can take either one or two arguments (in addition to
+    self). The first argument is "result", which is the error information from
+    pep8. The second argument, "logical", is required only for logical-line
+    fixes.
+
+    The fixer method can return the list of modified lines or None. An empty
+    list would mean that no changes were made. None would mean that only the
+    line reported in the pep8 error was modified. Note that the modified line
+    numbers that are returned are indexed at 1. This typically would correspond
+    with the line number reported in the pep8 error information.
+
     [fixed method list]
         - e111
         - e121,e122,e123,e124,e125,e126,e127,e128
@@ -114,6 +128,8 @@ class FixPEP8(object):
         - e401
         - e502
         - e701,e702
+        - e711
+        - e721
         - w291,w293
         - w391
         - w602,w603,w604
@@ -135,6 +151,7 @@ class FixPEP8(object):
         self.logical_end = None
         # method definition
         self.fix_e111 = self.fix_e101
+        self.fix_e128 = self.fix_e127
         self.fix_e202 = self.fix_e201
         self.fix_e203 = self.fix_e201
         self.fix_e211 = self.fix_e201
@@ -303,7 +320,7 @@ class FixPEP8(object):
             valid = valid_indents[row]
             got = rewrapper.rel_indent[row]
         else:
-            # line number from pep8 isn't a continuation line.  instead,
+            # Line number from pep8 isn't a continuation line. Instead,
             # compare our own function's result, look for the first mismatch,
             # and just hope that we take fewer than 100 iterations to finish.
             for row in range(0, len(original), 1):
@@ -312,7 +329,6 @@ class FixPEP8(object):
                 if valid != got:
                     break
         line = ls[0] + row
-        orig_line = self.source[line]
         # always pick the expected indent, for now.
         indent_to = valid[0]
         if fix_distinct and indent_to == 4:
@@ -322,10 +338,13 @@ class FixPEP8(object):
                 indent_to = valid[1]
 
         if got != indent_to:
-            self.source[line] = (
-                " " * (indent_to) + orig_line.lstrip()
-            )
-            return [line + 1]  # Line indexed at 1
+            orig_line = self.source[line]
+            new_line = ' ' * (indent_to) + orig_line.lstrip()
+            if new_line == orig_line:
+                return []
+            else:
+                self.source[line] = new_line
+                return [line + 1]  # Line indexed at 1
         else:
             return []
 
@@ -343,7 +362,23 @@ class FixPEP8(object):
         """The 'loose fingernails' indentation level error for hanging
         indents."""
         # fix by deleting whitespace to the correct level
-        return self._fix_reindent(result, logical)
+        modified_lines = self._fix_reindent(result, logical)
+        if modified_lines:
+            return modified_lines
+        else:
+            # Fallback
+            if not logical:
+                return []
+            logical_lines = logical[2]
+            line_index = result['line'] - 1
+            original_line = self.source[line_index]
+
+            fixed_line = (_get_indentation(logical_lines[0]) +
+                          original_line.lstrip())
+            if fixed_line == original_line:
+                return []
+            else:
+                self.source[line_index] = fixed_line
 
     def fix_e124(self, result, logical):
         """The 'loose fingernails' indentation level error for visual
@@ -354,23 +389,71 @@ class FixPEP8(object):
     def fix_e125(self, result, logical):
         """The 'often not visually distinct' error."""
         # fix by indenting the line in error to the next stop.
-        return self._fix_reindent(result, logical, fix_distinct=True)
+        modified_lines = self._fix_reindent(result, logical, fix_distinct=True)
+        if modified_lines:
+            return modified_lines
+        else:
+            # Fallback
+            line_index = result['line'] - 1
+            original_line = self.source[line_index]
+            self.source[line_index] = self.indent_word + original_line
 
     def fix_e126(self, result, logical):
         """The 'spectacular indent' error for hanging indents."""
         # fix by deleting whitespace to the left
-        return self._fix_reindent(result, logical)
+        modified_lines = self._fix_reindent(result, logical)
+        if modified_lines:
+            return modified_lines
+        else:
+            # Fallback
+            if not logical:
+                return []
+            logical_lines = logical[2]
+            line_index = result['line'] - 1
+            original = self.source[line_index]
+
+            fixed = (_get_indentation(logical_lines[0]) +
+                     self.indent_word + original.lstrip())
+            if fixed == original:
+                return []
+            else:
+                self.source[line_index] = fixed
 
     def fix_e127(self, result, logical):
         """The 'interpretive dance' indentation error."""
-        # fix by deleting whitespace to the correct level
-        return self._fix_reindent(result, logical)
+        # Fix by inserting/deleting whitespace to the correct level.
+        modified_lines = self._fix_reindent(result, logical)
+        if modified_lines:
+            return modified_lines
+        else:
+            # Fallback
+            return self._align_visual_indent(result, logical)
 
-    def fix_e128(self, result, logical):
-        """The 'I just wrap long lines with a line break in the middle of my
-        argument list' indentation error."""
-        # fix by deleting whitespace to the correct level
-        return self._fix_reindent(result, logical)
+    def _align_visual_indent(self, result, logical):
+        """Correct visual indent.
+
+        This includes over (E127) and under (E128) indented lines.
+
+        """
+        if not logical:
+            return []
+        logical_lines = logical[2]
+        line_index = result['line'] - 1
+        original = self.source[line_index]
+        fixed = original
+
+        if '(' in logical_lines[0]:
+            fixed = logical_lines[0].find('(') * ' ' + original.lstrip()
+        elif logical_lines[0].rstrip().endswith('\\'):
+            fixed = (_get_indentation(logical_lines[0]) +
+                     self.indent_word + original.lstrip())
+        else:
+            return []
+
+        if fixed == original:
+            return []
+        else:
+            self.source[line_index] = fixed
 
     def fix_e201(self, result):
         line_index = result['line'] - 1
@@ -590,7 +673,7 @@ class FixPEP8(object):
 
         fixed_source = (target[:c] + self.newline +
                         _get_indentation(target) + self.indent_word +
-                        target[c:].lstrip())
+                        target[c:].lstrip('\n\r \t\\'))
         self.source[result['line'] - 1] = fixed_source
 
     def fix_e702(self, result, logical):
@@ -814,13 +897,24 @@ def _shorten_line(tokens, source, target, indentation, indent_word, newline,
                          len(indent_word))):
                     continue
             first = source[:offset - len(indentation)]
-            second = (indentation + indent_word +
+
+            second_indent = indentation
+            if first.rstrip().endswith('('):
+                second_indent += indent_word
+            elif '(' in first:
+                second_indent += ' ' * (1 + first.find('('))
+            else:
+                second_indent += indent_word
+
+            second = (second_indent +
                       source[offset - len(indentation):].lstrip())
             if not second.strip():
                 continue
+
             # Don't modify if lines are not short enough
-            if (len(first) > max_line_width_minus_indentation or
-                    len(second) > max_line_width_minus_indentation):
+            if len(first) > max_line_width_minus_indentation:
+                continue
+            if len(second) > MAX_LINE_WIDTH:  # Already includes indentation
                 continue
             # Do not begin a line with a comma
             if second.lstrip().startswith(','):
@@ -832,11 +926,7 @@ def _shorten_line(tokens, source, target, indentation, indent_word, newline,
                 fixed = first + ' \\' + newline + second
             else:
                 fixed = first + newline + second
-            try:
-                ret = compile(fixed, '<string>', 'exec')
-            except SyntaxError:
-                continue
-            if ret:
+            if check_syntax(fixed):
                 return indentation + fixed
     return None
 
@@ -1133,8 +1223,8 @@ class Wrapper(object):
 
         """
 
-        # what follows is an adjusted version of
-        # pep8.py:continuation_line_indentation.  All of the comments have been
+        # What follows is an adjusted version of
+        # pep8.py:continuation_line_indentation. All of the comments have been
         # stripped and the 'yield' statements replaced with 'pass'.
         tokens = self.tokens
         if not tokens:
@@ -1170,11 +1260,11 @@ class Wrapper(object):
                            token_type not in (tokenize.NL, tokenize.NEWLINE))
 
             if newline:
-                # this is where the differences start.  instead of looking at
+                # This is where the differences start. Instead of looking at
                 # the line and determining whether the observed indent matches
                 # our expectations, we decide which type of indentation is in
-                # use at the given indent level, and return the offset.  this
-                # algorithm is succeptable to "carried errors", but should
+                # use at the given indent level, and return the offset. This
+                # algorithm is susceptible to "carried errors", but should
                 # through repeated runs eventually solve indentation for
                 # multi-line expressions less than PEP8_PASSES_MAX lines long.
 
@@ -1185,7 +1275,7 @@ class Wrapper(object):
                 else:
                     open_row = 0
 
-                # that's all we get to work with.  this code attempts to
+                # That's all we get to work with. This code attempts to
                 # "reverse" the below logic, and place into the valid indents
                 # list
                 vi = []
@@ -1340,16 +1430,23 @@ def break_multi_line(source_text, newline, indent_word):
     Return None if a break is not possible.
 
     """
-    if source_text.lstrip().startswith('#'):
-        return None
-
     # Handle special case only.
-    if ("'" not in source_text and '"' not in source_text and
-            '(' in source_text and source_text.rstrip().endswith(',')):
+    if ('(' in source_text and source_text.rstrip().endswith(',')):
         index = 1 + source_text.find('(')
         if index >= MAX_LINE_WIDTH:
             return None
 
+        # Make sure we are not in a string.
+        for quote in ['"', "'"]:
+            if quote in source_text:
+                if source_text.find(quote) < index:
+                    return None
+
+        # Make sure we are not in a comment.
+        if '#' in source_text:
+            if source_text.find('#') < index:
+                return None
+
         assert index < len(source_text)
         return (
             source_text[:index].rstrip() + newline +
@@ -1359,6 +1456,14 @@ def break_multi_line(source_text, newline, indent_word):
         return None
 
 
+def check_syntax(code):
+    """Return True if syntax is okay."""
+    try:
+        return compile(code, '<string>', 'exec')
+    except (SyntaxError, TypeError, UnicodeDecodeError):
+        return False
+
+
 def fix_file(filename, opts, output=sys.stdout):
     tmp_source = read_from_filename(filename)
 
@@ -1475,4 +1580,7 @@ def main():
 
 
 if __name__ == '__main__':
-    sys.exit(main())
+    try:
+        sys.exit(main())
+    except KeyboardInterrupt:
+        sys.exit(1)
