@@ -340,8 +340,8 @@ sql = 'update %s set %s %s' % (from_table,
         fixed = """
 
 sql = 'update %s set %s %s' % (from_table,
-                               ','.join(['%s=%s' % (col, col) for col in cols]
-                                        ),
+                               ','.join(
+                                   ['%s=%s' % (col, col) for col in cols]),
                                where_clause)
 """
         self._inner_setup(line)
@@ -494,6 +494,84 @@ def baz():
         self._inner_setup(line, options=['--select=E12'])
         self.assertEqual(self.result, line)
 
+    def test_e123(self):
+        line = """
+if True:
+    foo = (
+        )
+"""
+        fixed = """
+if True:
+    foo = (
+    )
+"""
+        self._inner_setup(line, options=['--select=E12'])
+        self.assertEqual(self.result, fixed)
+
+    def test_e125(self):
+        line = """
+for k, v in sys.modules.items():
+    if k in ('setuptools', 'pkg_resources') or (
+        not os.path.exists(os.path.join(v.__path__[0], '__init__.py'))):
+        sys.modules.pop(k)
+"""
+        fixed = """
+for k, v in sys.modules.items():
+    if k in ('setuptools', 'pkg_resources') or (
+            not os.path.exists(os.path.join(v.__path__[0], '__init__.py'))):
+        sys.modules.pop(k)
+"""
+        self._inner_setup(line, options=['--select=E12'])
+        self.assertEqual(self.result, fixed)
+
+    def test_e126(self):
+        line = """
+if True:
+    posted = models.DateField(
+            default=datetime.date.today,
+            help_text="help"
+    )
+"""
+        fixed = """
+if True:
+    posted = models.DateField(
+        default=datetime.date.today,
+        help_text="help"
+    )
+"""
+        self._inner_setup(line, options=['--select=E12'])
+        self.assertEqual(self.result, fixed)
+
+    def test_e127(self):
+        line = """
+if True:
+    if True:
+        chksum = (sum([int(value[i]) for i in xrange(0, 9, 2)]) * 7 -
+                          sum([int(value[i]) for i in xrange(1, 9, 2)])) % 10
+"""
+        fixed = """
+if True:
+    if True:
+        chksum = (sum([int(value[i]) for i in xrange(0, 9, 2)]) * 7 -
+                  sum([int(value[i]) for i in xrange(1, 9, 2)])) % 10
+"""
+        self._inner_setup(line, options=['--select=E12'])
+        self.assertEqual(self.result, fixed)
+
+    def test_e12_with_backslash(self):
+        line = r"""
+if True:
+    assert reeval == parsed, \
+            'Repr gives different object:\n  %r !=\n  %r' % (parsed, reeval)
+"""
+        fixed = r"""
+if True:
+    assert reeval == parsed, \
+        'Repr gives different object:\n  %r !=\n  %r' % (parsed, reeval)
+"""
+        self._inner_setup(line, options=['--select=E12'])
+        self.assertEqual(self.result, fixed)
+
     def test_e191(self):
         line = """
 while True:
@@ -888,7 +966,25 @@ if True:
 
 if True:
     print(111, 111, 111, 111, 222, 222, 222, 222, 222, 222, 222, 222,
-        222, 333, 333, 333, 333)
+          222, 333, 333, 333, 333)
+"""
+        self._inner_setup(line, options=['--select=E501'])
+        self.assertEqual(self.result, fixed)
+
+
+    def test_e501_alone_with_tuple(self):
+        line = """
+
+fooooooooooooooooooooooooooooooo000000000000000000000000 = [1,
+                                                            ('TransferTime', 'FLOAT')
+                                                           ]
+"""
+        fixed = """
+
+fooooooooooooooooooooooooooooooo000000000000000000000000 = [1,
+                                                            ('TransferTime',
+                                                             'FLOAT')
+                                                           ]
 """
         self._inner_setup(line, options=['--select=E501'])
         self.assertEqual(self.result, fixed)
@@ -963,6 +1059,27 @@ foo_bar_zap_bing_bang_boom(
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_e501_with_multiple_lines_and_quotes(self):
+        line = """
+
+if True:
+    xxxxxxxxxxx = xxxxxxxxxxxxxxxxx(xxxxxxxxxxx, xxxxxxxxxxxxxxxx={'xxxxxxxxxxxx': 'xxxxx',
+                                                                   'xxxxxxxxxxx': xx,
+                                                                   'xxxxxxxx': False,
+                                                                   })
+"""
+        fixed = """
+
+if True:
+    xxxxxxxxxxx = xxxxxxxxxxxxxxxxx(
+        xxxxxxxxxxx, xxxxxxxxxxxxxxxx={'xxxxxxxxxxxx': 'xxxxx',
+                                       'xxxxxxxxxxx': xx,
+                                       'xxxxxxxx': False,
+                                       })
+"""
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
     def test_e501_do_not_break_on_keyword(self):
         # We don't want to put a newline after equals for keywords as this
         # violates PEP 8.
@@ -1044,6 +1161,18 @@ if True:
         self._inner_setup(line)
         self.assertEqual(self.result, fixed)
 
+    def test_e701_with_escaped_newline(self):
+        line = "if True:\\\nprint True\n"
+        fixed = "if True:\n    print True\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
+    def test_e701_with_escaped_newline_and_spaces(self):
+        line = "if True:    \\   \nprint True\n"
+        fixed = "if True:\n    print True\n"
+        self._inner_setup(line)
+        self.assertEqual(self.result, fixed)
+
     def test_e702(self):
         line = "print 1; print 2\n"
         fixed = "print 1\nprint 2\n"
